@@ -78,11 +78,9 @@ class EvaluationManager:
         self,
         logger: Logger,
         chat_service: ChatService,
-        assistant_message_id: str,
     ):
         self._logger = logger
         self._chat_service = chat_service
-        self._assistant_message_id = assistant_message_id
         self._evaluations: dict[EvaluationMetricName, Evaluation] = {}
         self._evaluation_passed: bool = True
 
@@ -96,6 +94,7 @@ class EvaluationManager:
         self,
         selected_evaluation_names: list[EvaluationMetricName],
         loop_response: LanguageModelStreamResponse,
+        assistant_message_id: str,
     ) -> list[EvaluationMetricResult]:
         task_executor = SafeTaskExecutor(
             logger=self._logger,
@@ -106,6 +105,7 @@ class EvaluationManager:
                 self.execute_evaluation_call,
                 loop_response=loop_response,
                 evaluation_name=evaluation_name,
+                assistant_message_id=assistant_message_id,
             )
             for evaluation_name in selected_evaluation_names
         ]
@@ -126,6 +126,7 @@ class EvaluationManager:
         self,
         evaluation_name: EvaluationMetricName,
         loop_response: LanguageModelStreamResponse,
+        assistant_message_id: str,
     ) -> EvaluationMetricResult:
         self._logger.info(f"Processing tool call: {evaluation_name}")
 
@@ -133,13 +134,15 @@ class EvaluationManager:
 
         if evaluation_instance:
             # Execute the evaluation
-            await self._create_assistant_message(evaluation_instance)
+            await self._create_assistant_message(
+                evaluation_instance, assistant_message_id
+            )
             evaluation_metric_result: EvaluationMetricResult = (
                 await evaluation_instance.run(loop_response)
             )
             # show results to the user
             await self._show_message_assessment(
-                evaluation_instance, evaluation_metric_result
+                evaluation_instance, evaluation_metric_result, assistant_message_id
             )
 
             return evaluation_metric_result
@@ -182,6 +185,7 @@ class EvaluationManager:
         self,
         evaluation_instance: Evaluation,
         evaluation_metric_result: EvaluationMetricResult,
+        assistant_message_id: str,
     ) -> None:
         evaluation_assessment_message = (
             await evaluation_instance.evaluation_metric_to_assessment(
@@ -189,7 +193,7 @@ class EvaluationManager:
             )
         )
         await self._chat_service.modify_message_assessment_async(
-            assistant_message_id=self._assistant_message_id,
+            assistant_message_id=assistant_message_id,
             status=evaluation_assessment_message.status,
             title=evaluation_assessment_message.title,
             explanation=evaluation_assessment_message.explanation,
@@ -197,9 +201,11 @@ class EvaluationManager:
             type=evaluation_assessment_message.type,
         )
 
-    async def _create_assistant_message(self, evaluation_instance: Evaluation):
+    async def _create_assistant_message(
+        self, evaluation_instance: Evaluation, assistant_message_id: str
+    ):
         await self._chat_service.create_message_assessment_async(
-            assistant_message_id=self._assistant_message_id,
+            assistant_message_id=assistant_message_id,
             status=ChatMessageAssessmentStatus.PENDING,
             type=evaluation_instance.get_assessment_type(),
         )
