@@ -17,7 +17,7 @@ class OpenAINotInstalledError(ImportError):
 
 
 if importlib.util.find_spec("openai") is not None:
-    from openai import OpenAI
+    from openai import AsyncOpenAI, OpenAI
 else:
     raise OpenAINotInstalledError()
 
@@ -44,3 +44,29 @@ def get_openai_client(unique_settings: UniqueSettings | None = None) -> OpenAI:
         base_url=unique_settings.api.openai_proxy_url(),
         default_headers=default_headers,
     )
+
+
+def get_async_openai_client(
+    unique_settings: UniqueSettings | None = None,
+) -> AsyncOpenAI:
+    """Get an async OpenAI client instance.
+
+    Args:
+        unique_settings: Optional UniqueSettings instance
+
+    Returns:
+        AsyncOpenAI client instance
+
+    Raises:
+        OpenAINotInstalledError: If OpenAI package is not installed
+    """
+    if unique_settings is None:
+        unique_settings = UniqueSettings.from_env_auto()
+
+    default_headers = get_default_headers(unique_settings.app, unique_settings.auth)
+
+    return AsyncOpenAI(
+        api_key="dummy_key",
+        base_url=unique_settings.api.openai_proxy_url(),
+        default_headers=default_headers,
+    )
